'use strict';

require('dotenv/config');
var cac = require('cac');
var consola = require('consola');
var googleFontMetadata = require('google-font-metadata');
var colors = require('picocolors');
var queue = require('./queue-64813569.cjs');
require('@clack/prompts');
require('fs-extra');
require('pathe');
require('json-stringify-pretty-compact');
require('@fontsource-utils/generate');
require('p-queue');
require('flat');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var consola__default = /*#__PURE__*/_interopDefaultLegacy(consola);
var colors__default = /*#__PURE__*/_interopDefaultLegacy(colors);

var version = "0.2.0-beta.27";

const cli = cac.cac("fontsource");
cli.command("fetch [key]", "Fetch parsing metadata for all fonts").option("-f, --force", "Force parse all metadata").action(async (key, options) => {
  try {
    const finalKey = key ?? process.env.GOOGLE_API_KEY;
    if (!finalKey) {
      throw new Error("No API key provided.");
    }
    if (options.force) {
      consola__default["default"].info(
        `Parsing all metadata... ${colors__default["default"].bold(colors__default["default"].red("[FORCE]"))}`
      );
    } else {
      consola__default["default"].info("Parsing all metadata...");
    }
    await Promise.all([googleFontMetadata.fetchAPI(finalKey), googleFontMetadata.fetchVariable()]);
    await googleFontMetadata.parsev1(options.force, true);
    await googleFontMetadata.parsev2(options.force, true);
    await googleFontMetadata.generateAxis();
    await googleFontMetadata.parseVariable(true);
    await googleFontMetadata.parseIcons(options.force);
    await googleFontMetadata.parseLicenses();
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("build [...fonts]", "Build font packages").option("-f, --force", "Force rebuild all packages").option("-t, --test", "Build test fonts only").action(async (fonts, options) => {
  try {
    consola__default["default"].info(
      `Building packages... ${options.force ? colors__default["default"].bold(colors__default["default"].red("[FORCE]")) : ""}`
    );
    await queue.processGoogle(options, fonts);
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("create").action(async () => {
  try {
    await queue.create();
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("create-verify").option("-i, --id <id>", "ID of the font to verify").option("--cwd <cwd>", "Directory to run verification in").option("--ci", "Run in CI mode and throw errors instead of fancy prompts").action(async (options) => {
  try {
    await queue.verify({ font: options.id, ci: options.ci, cwd: options.cwd });
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.help();
cli.version(version);
cli.parse();
