import 'dotenv/config';
import { cac } from 'cac';
import consola from 'consola';
import { fetchAPI, fetchVariable, parsev1, parsev2, generateAxis, parseVariable, parseIcons, parseLicenses } from 'google-font-metadata';
import colors from 'picocolors';
import { p as processGoogle, c as create, v as verify } from './queue-d9717c32.mjs';
import '@clack/prompts';
import 'fs-extra';
import 'pathe';
import 'json-stringify-pretty-compact';
import '@fontsource-utils/generate';
import 'p-queue';
import 'flat';

var version = "0.2.0-beta.27";

const cli = cac("fontsource");
cli.command("fetch [key]", "Fetch parsing metadata for all fonts").option("-f, --force", "Force parse all metadata").action(async (key, options) => {
  try {
    const finalKey = key ?? process.env.GOOGLE_API_KEY;
    if (!finalKey) {
      throw new Error("No API key provided.");
    }
    if (options.force) {
      consola.info(
        `Parsing all metadata... ${colors.bold(colors.red("[FORCE]"))}`
      );
    } else {
      consola.info("Parsing all metadata...");
    }
    await Promise.all([fetchAPI(finalKey), fetchVariable()]);
    await parsev1(options.force, true);
    await parsev2(options.force, true);
    await generateAxis();
    await parseVariable(true);
    await parseIcons(options.force);
    await parseLicenses();
  } catch (error) {
    consola.error(error);
  }
});
cli.command("build [...fonts]", "Build font packages").option("-f, --force", "Force rebuild all packages").option("-t, --test", "Build test fonts only").action(async (fonts, options) => {
  try {
    consola.info(
      `Building packages... ${options.force ? colors.bold(colors.red("[FORCE]")) : ""}`
    );
    await processGoogle(options, fonts);
  } catch (error) {
    consola.error(error);
  }
});
cli.command("create").action(async () => {
  try {
    await create();
  } catch (error) {
    consola.error(error);
  }
});
cli.command("create-verify").option("-i, --id <id>", "ID of the font to verify").option("--cwd <cwd>", "Directory to run verification in").option("--ci", "Run in CI mode and throw errors instead of fancy prompts").action(async (options) => {
  try {
    await verify({ font: options.id, ci: options.ci, cwd: options.cwd });
  } catch (error) {
    consola.error(error);
  }
});
cli.help();
cli.version(version);
cli.parse();
